pub struct MemOp<F> {
pub operation: MemOpKind,
pub index: Witness,
pub value: Witness,
_phantom: PhantomData<F>,
}Expand description
Operation on a block of memory We can either write or read at an index in memory
Fields
operation: MemOpKindindex: Witnessarray index, it must be less than the array length
value: Witnessthe witness we are reading into (read), or the witness whose value is written (write)
_phantom: PhantomData<F>Implementations
Sourceimpl<F> MemOp<F>
impl<F> MemOp<F>
Sourcepub fn read_at_mem_index(index: Witness, value: Witness) -> Self
pub fn read_at_mem_index(index: Witness, value: Witness) -> Self
Creates a MemOp which reads from memory at index and inserts the read value
into the WitnessMap at value.
Sourcepub fn write_to_mem_index(index: Witness, value: Witness) -> Self
pub fn write_to_mem_index(index: Witness, value: Witness) -> Self
Creates a MemOp which writes value into memory at index.